/** \File NvmEeprom.hpp
 * \copyright (c) 2025 len0rd
 * \date   2025-01-09
 *
 * Very basic non-volatile memory handler to save and retrieve data
 * needed by the controller
 */
#ifndef __NVMEEPROM_H__
#define __NVMEEPROM_H__
#include <cstdint>

struct JoystickAxisCalibration
{
    /// Minimum value axis could be
    uint16_t min;
    /// average center point of axis
    uint16_t mid;
    /// max value axis could be
    uint16_t max;

    /// Check if the data in this struct makes sense
    /// Returns true if data might be valid, otherwise false
    bool valid() const;
} __attribute__((packed));

struct JoystickCalibration
{
    JoystickAxisCalibration x;
    JoystickAxisCalibration y;
} __attribute__((packed));

union NonVolatileMemory
{
    JoystickCalibration joystickCal;
    uint8_t rawBytes[sizeof(JoystickCalibration)] = {};
};

/// @brief Write the provided struct to EEPROM
void writeNvm(const NonVolatileMemory &nvm);
void writeCalibration(const JoystickCalibration&cal);

void readNvm(NonVolatileMemory &nvm);

#endif /* __NVMEEPROM_H__ */
